@@ -18,7 +18,6 @@ from django.urls import include, path
 
 urlpatterns = [
     path('', include('schema.urls')),
-    path('help/', include('help.urls')),
     path('api/', include('api.urls')),
     path('admin/', admin.site.urls),
     path('accounts/', include('django_registration.backends.activation.urls')),
@@ -26,4 +25,5 @@ urlpatterns = [
     path('', include('django_prometheus.urls')),
     path('ratings/', include('star_ratings.urls', namespace='ratings')),
     path('health/', include('health_check.urls')),
+    path('docs/', include('sphinxdoc.urls')),
 ]
