@@ -31,7 +31,7 @@ class ArchiveTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Archive
-        fields = ('name', 'type', 'max_width', 'max_height', 'sealed')
+        fields = ('name', 'type', 'max_size', 'sealed')
 
     @classmethod
     def render_id_owner(cls, value):
@@ -45,14 +45,6 @@ class ArchiveTable(tables.Table):
     def render_sealed(cls, value):
         return format_html(boolicon(value))
 
-    @classmethod
-    def render_max_width(cls, value):
-        return format_html("{}\"", value)
-
-    @classmethod
-    def render_max_height(cls, value):
-        return format_html("{}\"", value)
-
 
 class BatteryTable(tables.Table):
     class Meta:
@@ -312,7 +304,7 @@ class LensModelTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = LensModel
-        fields = ('model', 'mount', 'zoom', 'min_focal_length',
+        fields = ('model', 'mount', 'zoom', 'focal_length',
                   'max_aperture', 'autofocus', 'introduced')
 
     @classmethod
@@ -343,17 +335,6 @@ class LensModelTable(tables.Table):
     def render_max_aperture(cls, value):
         return format_html("<em>f</em>/{}", value)
 
-    @classmethod
-    def render_min_focal_length(cls, record):
-        if record.zoom is True:
-            mystr = format_html(
-                "{}-{}mm", record.min_focal_length, record.max_focal_length)
-        elif record.zoom is False:
-            mystr = format_html("{}mm", record.min_focal_length)
-        else:
-            mystr = format_html("?")
-        return mystr
-
     @classmethod
     def render_zoom(cls, value):
         return format_html(boolicon(value))
@@ -424,21 +405,13 @@ class NegativeSizeTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = NegativeSize
-        fields = ('name', 'width', 'height',
+        fields = ('name', 'size',
                   'crop_factor', 'area', 'aspect_ratio')
 
     @classmethod
     def render_name(cls, value, record):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:negativesize-detail', args=[record.id]), value)
 
-    @classmethod
-    def render_width(cls, value):
-        return format_html("{}mm", value)
-
-    @classmethod
-    def render_height(cls, value):
-        return format_html("{}mm", value)
-
     @classmethod
     def render_crop_factor(cls, value):
         return format_html("{}&times;", value)
@@ -456,7 +429,7 @@ class OrderTable(tables.Table):
     class Meta:
         attrs = {"class": "table table-hover"}
         model = Order
-        fields = ('id_owner', 'negative', 'width', 'height',
+        fields = ('id_owner', 'negative', 'size',
                   'added', 'printed', 'print', 'recipient')
 
     @classmethod
@@ -503,7 +476,7 @@ class PrintTable(tables.Table):
         attrs = {"class": "table table-hover"}
         model = Print
         fields = ('id_owner', 'negative', 'date',
-                  'width', 'height', 'own', 'archive')
+                  'size', 'own', 'archive')
 
     @classmethod
     def render_id_owner(cls, value):
@@ -513,14 +486,6 @@ class PrintTable(tables.Table):
     def render_negative(cls, value):
         return format_html("<a href=\"{}\">{}</a>", reverse('schema:negative-detail', args=[value.slug]), value)
 
-    @classmethod
-    def render_width(cls, value):
-        return format_html("{}\"", value)
-
-    @classmethod
-    def render_height(cls, value):
-        return format_html("{}\"", value)
-
     @classmethod
     def render_own(cls, value):
         return format_html(boolicon(value))
